<?php

use PrestaShop\PrestaShop\Core\Payment\PaymentOption;

if (!defined('_PS_VERSION_')) exit;

class Aqapey extends PaymentModule
{

    private $_html = '';
    private $_postErrors = array();

    public function __construct()
    {
        $this->name = 'Aqapey';
        $this->tab = 'payments_gateways';
        $this->version = '2.0';
        $this->author = 'info@aqayepardakht.ir';
        $this->currencies = true;
        $this->currencies_mode = 'checkbox';
        $this->controllers = array('request', 'verify');
        parent::__construct();
        $this->page = basename(__FILE__, '.php');
        $this->displayName = 'درگاه آقای پرداخت';
        $this->description = 'پرداخت از طریق درگاه آقای پرداخت';
        $this->confirmUninstall = 'آیا مطمئن هستید می خواهید جزئیات را حذف کنید ؟';
        $this->ps_versions_compliancy = array('min' => '1.7', 'max' => _PS_VERSION_);
        if (!sizeof(Currency::checkPaymentCurrencies($this->id)))
            $this->warning = 'لطفا واحد پولی درگاه را تنظیم نمایید';
        $config = Configuration::getMultiple(array('aqa_Pin', 'aqa_title', ''));
        if (!isset($config['aqa_Pin'],$config['aqa_title']))
            $this->warning = 'لطفا اطلاعات مرچنت درگاه را تنظیم نمایید';
    }

    public function install()
    {
        if (!parent::install() or !Configuration::updateValue('aqa_Pin', '') or !Configuration::updateValue('aqa_title', '') or !$this->registerHook('paymentOptions') or !$this->registerHook('paymentReturn'))
            return false;
        return true;
    }

    public function uninstall()
    {
        if (!Configuration::deleteByName('aqa_Pin') or !Configuration::deleteByName('aqa_title') or !parent::uninstall())
            return false;
        return true;
    }

    public function displayFormSettings()
    {
        $this->_html .= '<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
			<fieldset>
				<legend>تنظیمات</legend>
				<label> عنوان نمایشی درگاه آقای پرداخت </label>
				<div class="margin-form"><input type="text" size="30" name="aqa_title" id="aqa_title" value="'.Configuration::get('aqa_title').'" /></div>
				<label> پین درگاه آقای پرداخت </label>
				<div class="margin-form"><input type="text" size="30" name="aqa_Pin" id="aqa_Pin" value="'.Configuration::get('aqa_Pin').'" /></div>
				<center><input type="submit" name="submit" value="ذخیره" class="button" /></center>
			</fieldset>
		</form>';
    }

    public function displayConf()
    {
        $this->_html .= '<div class="conf confirm">تنظیمات بروز رسانی شد</div>';
    }

    public function displayErrors()
    {
        foreach ($this->_postErrors as $err)
            $this->_html .= '<div class="alert error">'. $err .'</div>';
    }

    public function getContent()
    {
        $this->displayAqayepardakhtIr();
        $this->postprocess();
        $this->displayFormSettings();
        return $this->_html;
    }

    private function postprocess()
    {
        if (isset($_POST['submit']))
        {
            if (empty($_POST['aqa_Pin']))
                $this->_postErrors[] = 'ورود پین درگاه آقای پرداخت الزامیست.';
            if (empty($_POST['aqa_title']))
                $this->_postErrors[] = 'ورود نام نمایشی درگاه آقای پرداخت الزامیست.';
            if (!sizeof($this->_postErrors))
            {
                Configuration::updateValue('aqa_Pin', $_POST['aqa_Pin']);
                Configuration::updateValue('aqa_title', $_POST['aqa_title']);
                return $this->displayConf();
            }
            return $this->displayErrors();
        }
    }

    private function displayAqayepardakhtIr()
    {
        $this->_html .= '<h2>درگاه آقای پرداخت</h2><img src="../modules/aqapey/logo.png" style="float:left; margin-right:15px;"><b>این افزونه به شما امکان پرداخت از طریق درگاه آقای پرداخت را برای شما فراهم می کند.</b><br /><br />';
    }

    public function execPayment($cart)
    {
        $send = 'http://panel.aqayepardakht.ir/startpay/';
       $address  = new Address(intval($cart->id_address_invoice));
       $customer = new Customer($address->id_customer);
        $redirect = $this->context->link->getModuleLink($this->name, 'verify', array('id_cart' => $cart->id), true);
        require_once(dirname(__FILE__) . '/aqa_payment_helper.class.php');
        $p = new Aqa_Payment_Helper(Configuration::get('aqa_Pin'));
        $data = ['amount'=>intval(ceil($cart->getOrderTotal(true, Cart::BOTH))),
            'invoice_id'=>$cart->id,
            'callback'=>$redirect,
			'description'=> 'نام پرداخت کننده : '.@$address->firstname.' '.@$address->lastname.' | ایمیل پرداخت کننده : '.@$customer->email.' | شماره پرداخت کننده : '.@$address->phone,
            'pin'=>Configuration::get('aqa_Pin'),
        ];
        $r = $p->paymentRequest($data);
        if ($r)
        {
            $link = $send.$r;
            $p->redirect(true,$link);
        }
        else
        {
            $message = $p->error;
            echo $message;
        }
    }

    public function confirmPayment($cart)
    {
        require_once(dirname(__FILE__) . '/aqa_payment_helper.class.php');
        $p = new Aqa_Payment_Helper(Configuration::get('aqa_Pin'));
        $r = $p->paymentVerify($_POST, intval(ceil($cart->getOrderTotal(true, Cart::BOTH))));

        return $r;
    }

    public function hookPaymentOptions($params)
    {
        if (!$this->active) return;
        //if (!$this->checkCurrency($params['cart'])) return;
        $cart = $this->context->cart;
        $total = Tools::displayPrice($cart->getOrderTotal(true, Cart::BOTH));
        $view = '<section><p class="payment_module"><img src="modules/aqapey/logo.png" width="50px" height="50px" alt="'.Configuration::get('aqa_title').'" />'.Configuration::get('aqa_title').' <br /></p></section>';
        $newOption = new PaymentOption();
        $newOption->setModuleName($this->name)->setCallToActionText(Configuration::get('aqa_title'))->setAction($this->context->link->getModuleLink($this->name, 'request', array(), true))->setAdditionalInformation($view);
        return array($newOption);
    }

}
